package com.fs.store.mapper;

import java.util.List;
import com.fs.store.domain.FsStoreCoupon;
import org.apache.ibatis.annotations.Select;

/**
 * 优惠券Mapper接口
 *
 * @author fs
 * @date 2022-03-15
 */
public interface FsStoreCouponMapper
{
    /**
     * 查询优惠券
     *
     * @param couponId 优惠券ID
     * @return 优惠券
     */
    public FsStoreCoupon selectFsStoreCouponById(Long couponId);

    /**
     * 查询优惠券列表
     *
     * @param fsStoreCoupon 优惠券
     * @return 优惠券集合
     */
    public List<FsStoreCoupon> selectFsStoreCouponList(FsStoreCoupon fsStoreCoupon);

    /**
     * 新增优惠券
     *
     * @param fsStoreCoupon 优惠券
     * @return 结果
     */
    public int insertFsStoreCoupon(FsStoreCoupon fsStoreCoupon);

    /**
     * 修改优惠券
     *
     * @param fsStoreCoupon 优惠券
     * @return 结果
     */
    public int updateFsStoreCoupon(FsStoreCoupon fsStoreCoupon);

    /**
     * 删除优惠券
     *
     * @param couponId 优惠券ID
     * @return 结果
     */
    public int deleteFsStoreCouponById(Long couponId);

    /**
     * 批量删除优惠券
     *
     * @param couponIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteFsStoreCouponByIds(Long[] couponIds);


    @Select("select * from fs_store_coupon where find_in_set(coupon_id,#{ids})")
    List<FsStoreCoupon> selectFsStoreCouponByIds(String ids);
}
